@@ -47,15 +47,15 @@ G_GNUC_EXTENSION typedef signed long long gint64;
 G_GNUC_EXTENSION typedef unsigned long long guint64;
 
 #define G_GINT64_CONSTANT(val)	(G_GNUC_EXTENSION (val##LL))
-#define G_GINT64_FORMAT "qi"
-#define G_GUINT64_FORMAT "qu"
+#define G_GINT64_FORMAT "lli"
+#define G_GUINT64_FORMAT "llu"
 
 #define GLIB_SIZEOF_VOID_P 4
 #define GLIB_SIZEOF_LONG   4
 #define GLIB_SIZEOF_SIZE_T 4
 
-typedef gint32  gssize;
-typedef guint32 gsize;
+typedef signed int gssize;
+typedef unsigned int gsize;
 
 #define GPOINTER_TO_INT(p)	((gint)   (p))
 #define GPOINTER_TO_UINT(p)	((guint)  (p))
@@ -72,12 +72,12 @@ typedef guint32 gsize;
 #define g_memmove(d,s,n) G_STMT_START { memmove ((d), (s), (n)); } G_STMT_END
 
 #define GLIB_MAJOR_VERSION 2
-#define GLIB_MINOR_VERSION 0
+#define GLIB_MINOR_VERSION 2
 #define GLIB_MICRO_VERSION 1
 
 #define G_OS_UNIX
 
-#define G_VA_COPY	__va_copy
+#define G_VA_COPY	va_copy
 
 #ifdef	__cplusplus
 #define	G_HAVE_INLINE	1
@@ -90,6 +90,9 @@ typedef guint32 gsize;
 #ifndef __cplusplus
 # define G_HAVE_ISO_VARARGS 1
 #endif
+#ifdef __cplusplus
+# define G_HAVE_ISO_VARARGS 1
+#endif
 
 /* gcc-2.95.x supports both gnu style and ISO varargs, but if -ansi
  * is passed ISO vararg support is turned off, and there is no work
@@ -163,8 +166,8 @@ union _GSystemThread
 #define GLIB_SYSDEF_POLLIN =1
 #define GLIB_SYSDEF_POLLOUT =4
 #define GLIB_SYSDEF_POLLPRI =2
-#define GLIB_SYSDEF_POLLERR =8
 #define GLIB_SYSDEF_POLLHUP =16
+#define GLIB_SYSDEF_POLLERR =8
 #define GLIB_SYSDEF_POLLNVAL =32
 
 #define G_MODULE_SUFFIX "so"
